import { ReferenceConfiguration } from '@readyapi/api-reference';
import { Request, Response } from 'express';

type ApiReferenceOptions = ReferenceConfiguration & {
    cdn?: string;
};
/**
 * The custom theme CSS for the API Reference.
 */
declare const customThemeCSS = "\n/* basic theme */\n.light-mode {\n  --scalar-color-1: #353535;\n  --scalar-color-2: #555555;\n  --scalar-color-3: #aeaeae;\n  --scalar-color-accent: #259dff;\n\n  --scalar-background-1: #fff;\n  --scalar-background-2: #f7f7f7;\n  --scalar-background-3: #dadada;\n  --scalar-background-accent: #E0F5FF;\n\n  --scalar-border-color: rgba(0, 0, 0, 0.1);\n}\n.dark-mode {\n  --scalar-color-1: rgba(255, 255, 255, 0.9);\n  --scalar-color-2: rgba(255, 255, 255, 0.62);\n  --scalar-color-3: rgba(255, 255, 255, 0.44);\n  --scalar-color-accent: #8ab4f8;\n\n  --scalar-background-1: #1a1a1a;\n  --scalar-background-2: #252525;\n  --scalar-background-3: #323232;\n  --scalar-background-accent: #8ab4f81f;\n\n  --scalar-border-color: rgba(255, 255, 255, 0.1);\n}\n\n/* Document Sidebar */\n.light-mode .t-doc__sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n  --scalar-sidebar-search-background: transparent;\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n}\n\n.dark-mode .sidebar {\n  --scalar-sidebar-background-1: var(--scalar-background-1);\n  --scalar-sidebar-item-hover-color: currentColor;\n  --scalar-sidebar-item-hover-background: var(--scalar-background-2);\n  --scalar-sidebar-item-active-background: var(--scalar-background-accent);\n  --scalar-sidebar-border-color: var(--scalar-border-color);\n  --scalar-sidebar-color-1: var(--scalar-color-1);\n  --scalar-sidebar-color-2: var(--scalar-color-2);\n  --scalar-sidebar-color-active: var(--scalar-color-accent);\n  --scalar-sidebar-search-background: transparent;\n  --scalar-sidebar-search-border-color: var(--scalar-border-color);\n  --scalar-sidebar-search-color: var(--scalar-color-3);\n}\n\n/* advanced */\n.light-mode {\n  --scalar-button-1: rgb(49 53 56);\n  --scalar-button-1-color: #fff;\n  --scalar-button-1-hover: rgb(28 31 33);\n\n  --scalar-color-green: #669900;\n  --scalar-color-red: #dc4a68;\n  --scalar-color-yellow: #edbe20;\n  --scalar-color-blue: #0277aa;\n  --scalar-color-orange: #fb892c;\n  --scalar-color-purple: #5203d1;\n\n  --scalar-scrollbar-color: rgba(0, 0, 0, 0.18);\n  --scalar-scrollbar-color-active: rgba(0, 0, 0, 0.36);\n}\n.dark-mode {\n  --scalar-button-1: #f6f6f6;\n  --scalar-button-1-color: #000;\n  --scalar-button-1-hover: #e7e7e7;\n\n  --scalar-color-green: #00b648;\n  --scalar-color-red: #dc1b19;\n  --scalar-color-yellow: #ffc90d;\n  --scalar-color-blue: #4eb3ec;\n  --scalar-color-orange: #ff8d4d;\n  --scalar-color-purple: #b191f9;\n\n  --scalar-scrollbar-color: rgba(255, 255, 255, 0.24);\n  --scalar-scrollbar-color-active: rgba(255, 255, 255, 0.48);\n}\n:root {\n  --scalar-radius: 3px;\n  --scalar-radius-lg: 3px;\n  --scalar-radius-xl: 3px;\n}\n";
/**
 * The HTML to load the @readyapi/api-reference package.
 */
declare const ApiReference: (options: ApiReferenceOptions) => string;
/**
 * The HTML template to render the API Reference.
 */
declare function apiReference(options: ApiReferenceOptions): (req: Request, res: Response) => void;

export { ApiReference, type ApiReferenceOptions, apiReference, customThemeCSS };
